@@ -1,4 +1,4 @@
-# Copyright 2023 BigFrames Authors
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,4 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-__version__ = "0.0.0"
+__version__ = "2.12.0"
+
+# {x-release-please-start-date}
+__release_date__ = "2025-07-23"
+# {x-release-please-end}
